@@ -7,7 +7,9 @@ from anonlink import concurrency
 from anonlink import entitymatch
 from anonlink import network_flow
 from anonlink import serialization
+from anonlink import similarities
 from anonlink import solving
+from anonlink import stats
 from anonlink import typechecking
 
 __version__ = pkg_resources.get_distribution('anonlink').version
